@@ -12,23 +12,31 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import TYPE_CHECKING, TypeVar, Union
+
 from selenium import webdriver
 from selenium.common.exceptions import TimeoutException
 from selenium.webdriver.support.ui import WebDriverWait
 
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
+if TYPE_CHECKING:
+    # noinspection PyUnresolvedReferences
+    from appium.webdriver.webdriver import WebDriver
+
+T = TypeVar('T', bound=Union['WebDriver', 'Activities'])
+
 
 class Activities(webdriver.Remote):
-    def start_activity(self, app_package, app_activity, **opts):
+    def start_activity(self: T, app_package: str, app_activity: str, **opts: str) -> T:
         """Opens an arbitrary activity during a test. If the activity belongs to
         another application, that application is started and the activity is opened.
 
         This is an Android-only method.
 
         Args:
-            app_package (str): The package containing the activity to start.
-            app_activity (str): The activity to start.
+            app_package: The package containing the activity to start.
+            app_activity: The activity to start.
 
         Keyword Args:
             app_wait_package (str): Begin automation after this package starts.
@@ -59,7 +67,7 @@ class Activities(webdriver.Remote):
         return self
 
     @property
-    def current_activity(self):
+    def current_activity(self: T) -> str:
         """Retrieves the current activity running on the device.
 
         Returns:
@@ -67,15 +75,18 @@ class Activities(webdriver.Remote):
         """
         return self.execute(Command.GET_CURRENT_ACTIVITY)['value']
 
-    def wait_activity(self, activity, timeout, interval=1):
+    def wait_activity(self: T, activity: str, timeout: int, interval: int = 1) -> bool:
         """Wait for an activity: block until target activity presents or time out.
 
         This is an Android-only method.
 
         Args:
-            activity (str): target activity
-            timeout (int): max wait time, in seconds
-            interval (int): sleep interval between retries, in seconds
+            activity: target activity
+            timeout: max wait time, in seconds
+            interval: sleep interval between retries, in seconds
+
+        Returns:
+            `True` if the target activity is shown
         """
         try:
             WebDriverWait(self, timeout, interval).until(
@@ -85,8 +96,8 @@ class Activities(webdriver.Remote):
             return False
 
     # pylint: disable=protected-access
-
-    def _addCommands(self):
+    # noinspection PyProtectedMember
+    def _addCommands(self) -> None:
         self.command_executor._commands[Command.GET_CURRENT_ACTIVITY] = \
             ('GET', '/session/$sessionId/appium/device/current_activity')
         self.command_executor._commands[Command.START_ACTIVITY] = \
